@@ -72,7 +72,6 @@ class Storage(object):
         self.session.add(event)
         self.session.commit()
 
-
     @property
     def jobs(self):
         session = self.session
@@ -102,6 +101,13 @@ class Storage(object):
         events = self.session.query(Event).filter_by(run_id=run_id).order_by(Event.id)
         return event_models_to_docs(events)
 
+    def failures(self):
+        events = self.session.query(Event)\
+            .filter_by(type='finished')\
+            .filter(Event.return_code!=0)\
+            .order_by(desc(Event.id)).limit(50)
+        return event_models_to_docs(events)
+
     def run_job_now(self, id):
         event = self.session.query(Job).filter_by(id=id).first()
         event.run_now = True
@@ -150,11 +156,11 @@ def event_models_to_docs(events):
         yield {
             'id': event.id,
             'datetime': event.datetime,
-            'run_id': UUID(hex=event.run_id),
+            'run_id': event.run_id,
             'host': event.host,
             'return_code': event.return_code,
             'type': event.type,
-            'run_id': event.run_id,
+            'job_id': event.job_id,
         }
 
 
